==> asbru-0.0.9.crate: asbru-0.0.9/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.0.9]

#### Fix

-   Better with good docker image

## [0.0.8]

### Fix

-   Add heroku build & push & release for schema 1

## [0.0.7]

### Misc

-   Publish dirty :-)

## [0.0.6]

### Misc

-   Fix release (bis)

## [0.0.5]

### Misc

-   Release a new version
-   Workflow Fixed

## [0.0.4]

### Feat

-   Compilable codegen
-   First MVP directives
-   Heroku build

## [0.0.3]

### Feat

-   First draft for object's generation

### Misc

-   Work on architecture draft

## [0.0.2]

### Feat

-   Basic application structure for interacting with the cli
-   Open & Parse Schema
-   Add a Cargo.toml generation
-   Readme is better now

## [0.1.0]

### Added

-   Boot repo

[Unreleased]: https://github.com/Miaxos/asbru/compare/v0.0.9...HEAD

[0.0.9]: https://github.com/Miaxos/asbru/compare/v0.0.8...v0.0.9

[0.0.8]: https://github.com/Miaxos/asbru/compare/v0.0.7...v0.0.8

[0.0.7]: https://github.com/Miaxos/asbru/compare/v0.0.6...v0.0.7

[0.0.6]: https://github.com/Miaxos/asbru/compare/v0.0.5...v0.0.6

[0.0.5]: https://github.com/Miaxos/asbru/compare/v0.0.4...v0.0.5

[0.0.4]: https://github.com/Miaxos/asbru/compare/v0.0.3...v0.0.4

[0.0.3]: https://github.com/Miaxos/asbru/compare/v0.0.2...v0.0.3

[0.0.2]: https://github.com/Miaxos/asbru/compare/v0.0.1...v0.0.2

==> asbru-0.0.11.crate: asbru-0.0.11/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.0.11]

### Fix

-   Add env variable for PORT, Should fix dockerfile for heroku

## [0.0.10]

### Misc

-   Expose port

## [0.0.9]

#### Fix

-   Better with good docker image

## [0.0.8]

### Fix

-   Add heroku build & push & release for schema 1

## [0.0.7]

### Misc

-   Publish dirty :-)

## [0.0.6]

### Misc

-   Fix release (bis)

## [0.0.5]

### Misc

-   Release a new version
-   Workflow Fixed

## [0.0.4]

### Feat

-   Compilable codegen
-   First MVP directives
-   Heroku build

## [0.0.3]

### Feat

-   First draft for object's generation

### Misc

-   Work on architecture draft

## [0.0.2]

### Feat

-   Basic application structure for interacting with the cli
-   Open & Parse Schema
-   Add a Cargo.toml generation
-   Readme is better now

## [0.1.0]

### Added

-   Boot repo

[Unreleased]: https://github.com/Miaxos/asbru/compare/v0.0.11...HEAD

[0.0.11]: https://github.com/Miaxos/asbru/compare/v0.0.10...v0.0.11

[0.0.10]: https://github.com/Miaxos/asbru/compare/v0.0.9...v0.0.10

[0.0.9]: https://github.com/Miaxos/asbru/compare/v0.0.8...v0.0.9

[0.0.8]: https://github.com/Miaxos/asbru/compare/v0.0.7...v0.0.8

[0.0.7]: https://github.com/Miaxos/asbru/compare/v0.0.6...v0.0.7

[0.0.6]: https://github.com/Miaxos/asbru/compare/v0.0.5...v0.0.6

[0.0.5]: https://github.com/Miaxos/asbru/compare/v0.0.4...v0.0.5

[0.0.4]: https://github.com/Miaxos/asbru/compare/v0.0.3...v0.0.4

[0.0.3]: https://github.com/Miaxos/asbru/compare/v0.0.2...v0.0.3

[0.0.2]: https://github.com/Miaxos/asbru/compare/v0.0.1...v0.0.2
